@@ -28,7 +28,7 @@ ecospat.boyce <- function(fit, obs, nclass = 0, window.w = "default", res = 100,
 # }
   if (inherits(fit, "SpatRaster")) {
     if (is.data.frame(obs) || is.matrix(obs)) {
-      obs <- terra::extract(fit, as.data.frame(obs),ID=FALSE)
+      obs <- terra::extract(fit, as.matrix(obs))
       obs <- as.numeric(obs[,1]) ##need to be a vector
     }
     fit <- terra::values(fit,na.rm=T)
